export default {
    "index": 11,
    "lineNumber": 1,
    "column": 12,
    "message": "Cannot use keyword 'await' outside an async function"
};
